/*
 *    NzdlCollectionInfo.java
 *    Copyright (C) 2001 New Zealand Digital Library Project
 *
 *    This program is free software; you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation; either version 2 of the License, or
 *    (at your option) any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program; if not, write to the Free Software
 *    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

//the package we're in
package org.nzdl.gsdl.service;

/** gsdl corba stuff */
import org.nzdl.gsdl.corba.gsdlInterface.*;
import org.nzdl.gsdl.util.*;
import java.util.*;

/**
 * An object that stores information on a collection. Information is obtained from
 * {@link NzdlService NzdlService.getCollectionInfo(name)}
 * Easily interrogated by a user.
 *
 * @author Stuart Yeates  (say1@cs.waikato.ac.nz)
 * @author Aziz Mahoui    (amahoui@yahoo.com)
 * @author Gordon Paynter (paynter@cs.waikato.ac.nz)
 * @author Dave Nichols   (daven@cs.waikato.ac.nz)
 * @author Brett Sheeran (bsheeran@xtra.co.nz) (comments)
 * @version $Revision: 2320 $
 */
public class NzdlCollectionInfo extends Object {

  private corbaColInfoResponse m_Info = null;
    private HashMap metaMap;

  /**
   * Create an instance of NzdlCollectionInfo.
   */
    public NzdlCollectionInfo( corbaColInfoResponse _info ) {
	m_Info = _info;
	metaMap = new HashMap();

	if (!getHTTPDomain().equals(""))
	    System.out.println("getHTTPDomain working !");
	if (!getName().equals(""))
	    System.out.println("getName working !");
	if (!getHostName().equals(""))
	    System.out.println("getHostName working !");

	for (int i=0;i< m_Info.collectionMeta.names.length; i++) {
	    metaMap.put( NzdlCorbaFactory.toString(m_Info.collectionMeta.names[i]), NzdlCorbaFactory.toString(m_Info.collectionMeta.values[i]));
	    //System.err.println(NzdlCorbaFactory.toString(m_Info.collectionMeta.values[i]));
	}

    }

  /**
   * Returns the corbaInfoResponse.
   */
  public corbaColInfoResponse getInfo(){
    return m_Info;
  }

  /**
   * Returns the name of a collection. <br>
   * Pre: Created instance of NzdlCollectionInfo. Used
   * {@link NzdlService NzdlService.getCollectionInfo(name)}
   * to extract collection information.
   * @return A string representing the name of the collection.
   */
  public String getName() {
    return NzdlCorbaFactory.toString( m_Info.shoftInfo.name ) ;
  }
  /**
   * Return the Hostname
   */
  public String getHostName() {
    return NzdlCorbaFactory.toString( m_Info.shoftInfo.host ) ;
  }
  /**
   * Returns HTTP Prefix
   */
  public String getHTTPPrefix() {
    //return m_Info.httpprefix.text.toString();
     return NzdlCorbaFactory.toString( m_Info.httpprefix ) ;
  }

  /**
   * Returns HTTP Domain
   */
  public String getHTTPDomain() {
    return NzdlCorbaFactory.toString( m_Info.httpdomain ) ;
  }

  /**
   * Returns reseptionist
   */
  public String getReceptionist() {
    return NzdlCorbaFactory.toString( m_Info.receptionist ) ;
  }

  /**
   * Returns true if collection is public. <br>
   * Pre: Created instance of NzdlCollectionInfo. Used
   * {@link NzdlService NzdlService.getCollectionInfo(name)}
   * to extract collection information.
   * @return Boolean true if collection is public, otherwise returns false.
   */
  public boolean isPublic() {
    return m_Info.isPublic;
  }

  /**
   * Returns true if collection is a beta version. <br>
   * Pre: Created instance of NzdlCollectionInfo. Used
   * {@link NzdlService NzdlService.getCollectionInfo(name)}
   * to extract collection information.
   * @return Boolean true if collection is a beta version, otherwise returns false.
   */
  public boolean isBeta() {
    return m_Info.isBeta;
  }

  /**
   * Returns an integer representation of build date. <br>
   * Pre: Created instance of NzdlCollectionInfo. Used
   * {@link NzdlService NzdlService.getCollectionInfo(name)}
   * to extract collection information.
   * @return Integer representation of date.
   */
  public long getBuildDate() {
    return m_Info.buildDate;
  }

  /**
   * Returns the number of documents in a collection. <br>
   * Pre: Created instance of NzdlCollectionInfo. Used
   * {@link NzdlService NzdlService.getCollectionInfo(name)}
   * to extract collection information.
   * @return An integer representing the number of documents in the collection.
   */
  public long getNumOfDocs() {
    return m_Info.numDocs;
  }

  /**
   * Returns the number of words in a collection. <br>
   * Pre: Created instance of NzdlCollectionInfo. Used
   * {@link NzdlService NzdlService.getCollectionInfo(name)}
   * to extract collection information.
   * @return An integer representing the number of words in the collection.
   */
  public long getNumOfWords() {
    return m_Info.numWords;
  }

  /**
   * Returns the number of bytes in the collection. <br>
   * Pre: Created instance of NzdlCollectionInfo. Used
   * {@link NzdlService NzdlService.getCollectionInfo(name)}
   * to extract collection information.
   * @return An integer representing the number of bytes in the collection.
   */
  public long getNumOfBytes() {
    return m_Info.numBytes;
  }

  /**
   * Returns a string describing collection details. <br>
   * Pre: Created instance of NzdlCollectionInfo. Used
   * {@link NzdlService NzdlService.getCollectionInfo(name)}
   * to extract collection information.
   * @return A string describing collection details such as: collection name;
   * isPublic; isBeta; buildDate; numOfDocs; numOfWords; numOfBytes
   */
  public String toString() {
    StringBuffer buf = new  StringBuffer(1000);
    buf.append("coll name=\"").append(getName());
    buf.append("\" isPublic=").append(isPublic());
    buf.append(" isBeta=").append(isBeta());
    buf.append(" buildDate=").append(getBuildDate());
    buf.append(" numOfDocs=").append(getNumOfDocs());
    buf.append(" numOfWords=").append(getNumOfWords());
    buf.append(" numOfBytes=").append(getNumOfBytes());
    return buf.toString();
  }

  /**
   * Not currently implemented
   */
  public void print() {
	/* daven@cs.waikato.ac.nz */
	//System.out.println("Collection Information--------------");
	//System.out.println("Collection Name = " + this.getName());
	//System.out.println("Collection Name = " + m_info.getName());
	
  }


    

    /* return the metadata Map */

    public Map getCollectionMetaData() {
	return metaMap;
    }


    public boolean isCollectionDescription() {
	return metaMap.containsKey(NzdlConstants.COLLECTION_DESCRIPTION);
    }

    /* this is currently leaving \n in the text whereas the 
       version using nzdlService.getMetaData doesn't,
       try the tcc description text to see an example,
       something to do with the use of CorbaFactory method 
       in the constructor is not quite right - Stuart will 
       know what is wrong   -  Dave */

    public String getCollectionDescription() {
	return (String) metaMap.get(NzdlConstants.COLLECTION_DESCRIPTION);
    }

    public boolean isCollectionIcon() {
	return metaMap.containsKey(NzdlConstants.ICON);
    }

    public String getCollectionIcon() {
	return (String) metaMap.get(NzdlConstants.ICON);
    }

    public boolean isCollectionSmallIcon() {
	return metaMap.containsKey(NzdlConstants.SMALL_ICON);
    }

    public String getCollectionSmallIcon() {
	return (String) metaMap.get(NzdlConstants.SMALL_ICON);
    }

    public boolean isLongCollectionName() {
	return metaMap.containsKey(NzdlConstants.LONG_COLLECTION_NAME);
    }

    public String getLongCollectionName() {
	return (String) metaMap.get(NzdlConstants.LONG_COLLECTION_NAME);
    }

}








